PackageLikes class
Public like count of a package.
Unlike the authenticated like-status API, this information is public.
- Mixed-in types
- Annotations
-
- @MappableClass.new()
Constructors
- PackageLikes({required String package, required int likes})
-
Creates a package-like count.
const
Properties
-
copyWith
→ PackageLikesCopyWith<
PackageLikes, PackageLikes, PackageLikes> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- likes → int
-
The package's public like count.
final
- package → String
-
The package whose likes were counted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fromJson → const PackageLikes Function(String json)
- Decodes a package-like count from JSON.
-
fromMap
→ const PackageLikes Function(Map<
String, dynamic> map) - Decodes a package-like count from a map.